﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.SilverlightMediaFramework.Player;
using Microsoft.SilverlightMediaFramework.Logging;
using Microsoft.SilverlightMediaFramework.Data.Settings;
using Microsoft.SilverlightMediaFramework;
using Microsoft.Web.Media.SmoothStreaming;

namespace SMFPlayerTest
{
    [TemplateVisualState(Name = "Hide", GroupName = "SuggestionStates")]
    [TemplateVisualState(Name = "Show", GroupName = "SuggestionStates")]
    public class SMFPlayer : Player
    {
        private SettingsClient m_settingsGetter;
        private SMFPlayerTestSettings m_settings = new SMFPlayerTestSettings();
        private SMFPlayerTestDataClient m_client = null;
        public override void OnApplyTemplate()
        {
            VisualStateManager.GoToState(this, "Hide", true); 

            Logger.Log(
                new DebugLog
                {
                    Message = "Hello from OnApplyTemplate!",
                    Sender = this
                });

            m_settingsGetter = new SettingsClient(
                new Uri("http://localhost:10205/SMFPlayerSettings.xml"));

            m_settingsGetter.RequestCompleted +=
                new EventHandler<SimpleEventArgs<SettingsBase>>(m_settingsGetter_RequestCompleted);

            m_settingsGetter.Fetch();

            this.mediaElement.MediaEnded += new RoutedEventHandler(mediaElement_MediaEnded);
            this.mediaElement.MediaOpened += new RoutedEventHandler(mediaElement_MediaOpened);
            this.mediaElement.SeekCompleted += new EventHandler<SeekCompletedEventArgs>(mediaElement_SeekCompleted);

            base.OnApplyTemplate();
        }

        void mediaElement_SeekCompleted(object sender, Microsoft.Web.Media.SmoothStreaming.SeekCompletedEventArgs e)
        {
            VisualStateManager.GoToState(this, "Hide", true);
        }

        void mediaElement_MediaOpened(object sender, RoutedEventArgs e)
        {
            VisualStateManager.GoToState(this, "Hide", true);
        }

        void mediaElement_MediaEnded(object sender, RoutedEventArgs e)
        {
            m_client = new SMFPlayerTestDataClient(new Uri("http://localhost:10205/Suggestions.xml"));
            m_client.FetchCompleted +=
                new EventHandler<SimpleEventArgs<SMFPlayerTestSuggestion[]>>(m_client_FetchCompleted);
            m_client.Fetch();
        }

        void m_client_FetchCompleted(object sender, SimpleEventArgs<SMFPlayerTestSuggestion[]> e)
        {
            for (int c = 1; c <= 3; c++)
            {
                Button btn = (Button)GetTemplateChild("Button" + c.ToString());
                btn.Tag = e.Result[c - 1].Url;
                btn.Content = e.Result[c - 1].DisplayName;
            }

            VisualStateManager.GoToState(this, "Show", true); 
        }

        void m_settingsGetter_RequestCompleted(object sender, SimpleEventArgs<SettingsBase> e)
        {
            SettingsBase settingsBase = e.Result;
            m_settings.Merge(settingsBase);

            this.mediaElement.SmoothStreamingSource = m_settings.VideoPlayerSource;
            this.mediaElement.AutoPlay = (bool)m_settings.AutoStartVideo;

            return;
        }
    }
}
